'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const pandora_service_logger_1 = require("pandora-service-logger");
/**
 * Class ServiceLogger
 */
class ServiceLogger {
    constructor(serviceCore) {
        const serviceId = serviceCore.getServiceId();
        this.prefix = `[appName: ${serviceCore.context.appName}, processName: ${serviceCore.context.processName}, workMode: ${serviceCore.workMode}] `;
        const defaultLoggerManager = pandora_service_logger_1.DefaultLoggerManager.getInstance();
        this.logger = defaultLoggerManager.createLogger(serviceId, {
            stdoutLevel: 'NONE',
            level: 'INFO',
            type: 'date',
            dir: pandora_service_logger_1.DefaultLoggerManager.getPandoraLogsDir()
        });
    }
    debug(...args) {
        args = this.doPrefix(args);
        this.logger.debug(...args);
    }
    warn(...args) {
        args = this.doPrefix(args);
        this.logger.warn(...args);
    }
    info(...args) {
        args = this.doPrefix(args);
        this.logger.info(...args);
    }
    error(...args) {
        args = this.doPrefix(args);
        this.logger.error(...args);
    }
    log(...args) {
        args = this.doPrefix(args);
        this.logger.info(...args);
    }
    write(...args) {
        this.logger.write(...args);
    }
    doPrefix(args) {
        if (typeof args[0] === 'string') {
            args[0] = this.prefix + args[0];
        }
        return args;
    }
}
exports.default = ServiceLogger;
//# sourceMappingURL=ServiceLogger.js.map